# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs

__all__ = ['NetworkStorageArgs', 'NetworkStorage']

@pulumi.input_type
class NetworkStorageArgs:
    def __init__(__self__, *,
                 data_center_id: pulumi.Input[str],
                 name: pulumi.Input[str],
                 size: pulumi.Input[int]):
        """
        The set of arguments for constructing a NetworkStorage resource.
        """
        pulumi.set(__self__, "data_center_id", data_center_id)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "size", size)

    @property
    @pulumi.getter(name="dataCenterId")
    def data_center_id(self) -> pulumi.Input[str]:
        return pulumi.get(self, "data_center_id")

    @data_center_id.setter
    def data_center_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "data_center_id", value)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[str]:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def size(self) -> pulumi.Input[int]:
        return pulumi.get(self, "size")

    @size.setter
    def size(self, value: pulumi.Input[int]):
        pulumi.set(self, "size", value)


class NetworkStorage(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 data_center_id: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 size: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        """
        Create a NetworkStorage resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: NetworkStorageArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a NetworkStorage resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param NetworkStorageArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(NetworkStorageArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 data_center_id: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 size: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = NetworkStorageArgs.__new__(NetworkStorageArgs)

            if data_center_id is None and not opts.urn:
                raise TypeError("Missing required property 'data_center_id'")
            __props__.__dict__["data_center_id"] = data_center_id
            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
            if size is None and not opts.urn:
                raise TypeError("Missing required property 'size'")
            __props__.__dict__["size"] = size
            __props__.__dict__["network_storage"] = None
        super(NetworkStorage, __self__).__init__(
            'runpod:index:NetworkStorage',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None) -> 'NetworkStorage':
        """
        Get an existing NetworkStorage resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = NetworkStorageArgs.__new__(NetworkStorageArgs)

        __props__.__dict__["data_center_id"] = None
        __props__.__dict__["name"] = None
        __props__.__dict__["network_storage"] = None
        __props__.__dict__["size"] = None
        return NetworkStorage(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="dataCenterId")
    def data_center_id(self) -> pulumi.Output[str]:
        return pulumi.get(self, "data_center_id")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="networkStorage")
    def network_storage(self) -> pulumi.Output['outputs.NetworkStorage']:
        return pulumi.get(self, "network_storage")

    @property
    @pulumi.getter
    def size(self) -> pulumi.Output[int]:
        return pulumi.get(self, "size")

