# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'PodEnvArgs',
    'SavingsPlanInputArgs',
]

@pulumi.input_type
class PodEnvArgs:
    def __init__(__self__, *,
                 key: pulumi.Input[str],
                 value: pulumi.Input[str]):
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> pulumi.Input[str]:
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: pulumi.Input[str]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def value(self) -> pulumi.Input[str]:
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: pulumi.Input[str]):
        pulumi.set(self, "value", value)


@pulumi.input_type
class SavingsPlanInputArgs:
    def __init__(__self__, *,
                 plan_length: pulumi.Input[str],
                 upfront_cost: pulumi.Input[float]):
        pulumi.set(__self__, "plan_length", plan_length)
        pulumi.set(__self__, "upfront_cost", upfront_cost)

    @property
    @pulumi.getter(name="planLength")
    def plan_length(self) -> pulumi.Input[str]:
        return pulumi.get(self, "plan_length")

    @plan_length.setter
    def plan_length(self, value: pulumi.Input[str]):
        pulumi.set(self, "plan_length", value)

    @property
    @pulumi.getter(name="upfrontCost")
    def upfront_cost(self) -> pulumi.Input[float]:
        return pulumi.get(self, "upfront_cost")

    @upfront_cost.setter
    def upfront_cost(self, value: pulumi.Input[float]):
        pulumi.set(self, "upfront_cost", value)


